@@ -21,7 +21,7 @@
  */
 
 /** \file common.h
-    \brief Contains basic defines for debug messages
+    \brief Contains basic defines
     \ingroup libgerbv
 */
 
@@ -38,5 +38,17 @@
 #define __FUNCTION__ __FUNCTION2(__FILE__,__LINE__)
 #endif
 
+#include "gettext.h"
+#define _(str) gettext(str)
+#ifdef ENABLE_NLS
+# ifdef gettext_noop
+#  define N_(str) gettext_noop(str)
+# else
+#  define N_(str) (str)
+# endif
+#else
+# define N_(str) (str)
+#endif
+
 #endif /* __COMMON_H__ */
 
