@@ -43,6 +43,7 @@
 #include "draw.h"
 #include "draw-gdk.h"
 #include <cairo.h>
+#include "common.h"
 
 #define dprintf if(DEBUG) printf
 
@@ -313,7 +314,7 @@ gerbv_draw_amacro(cairo_t *cairoTarget, cairo_operator_t clearOperator,
     int handled = 1;  
     gerbv_simplified_amacro_t *ls = s;
 
-    dprintf("Drawing simplified aperture macros:\n");
+    dprintf(_("Drawing simplified aperture macros:\n"));
     if (usesClearPrimative)
     	cairo_push_group (cairoTarget);
     while (ls != NULL) {
@@ -369,20 +370,23 @@ gerbv_draw_amacro(cairo_t *cairoTarget, cairo_operator_t clearOperator,
 			draw_fill (cairoTarget, drawMode, selectionInfo, image, net);
 		}
 	    } else if (ls->type == GERBV_APTYPE_MACRO_MOIRE) {
-		gdouble diameter, gap;
+		gdouble diameter, diameterDifference;
 		int circleIndex;
 		
 		cairo_translate (cairoTarget, ls->parameter[MOIRE_CENTER_X],
 			       ls->parameter[MOIRE_CENTER_Y]);
 		cairo_rotate (cairoTarget, ls->parameter[MOIRE_ROTATION] * M_PI/180);
 		diameter = ls->parameter[MOIRE_OUTSIDE_DIAMETER] -  ls->parameter[MOIRE_CIRCLE_THICKNESS];
-		gap = ls->parameter[MOIRE_GAP_WIDTH] + ls->parameter[MOIRE_CIRCLE_THICKNESS];
+		diameterDifference = 2*(ls->parameter[MOIRE_GAP_WIDTH] +
+			ls->parameter[MOIRE_CIRCLE_THICKNESS]);
 		cairo_set_line_width (cairoTarget, ls->parameter[MOIRE_CIRCLE_THICKNESS]);
 		
 		for (circleIndex = 0; circleIndex < (int)ls->parameter[MOIRE_NUMBER_OF_CIRCLES];  circleIndex++) {
-		    gdouble currentDiameter = (diameter - gap * (float) circleIndex);
-		    gerbv_draw_circle (cairoTarget, currentDiameter);
-		    draw_stroke (cairoTarget, drawMode, selectionInfo, image, net);
+		    gdouble currentDiameter = (diameter - diameterDifference * (float) circleIndex);
+		    if (currentDiameter >= 0){
+				gerbv_draw_circle (cairoTarget, currentDiameter);
+				draw_stroke (cairoTarget, drawMode, selectionInfo, image, net);
+		    }
 		}
 		
 		gdouble crosshairRadius = (ls->parameter[MOIRE_CROSSHAIR_LENGTH] / 2.0);
@@ -947,7 +951,7 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 								  drawMode, selectionInfo, image, net);
 						break;   
 					default :
-						GERB_MESSAGE("Unknown aperture type\n");
+						GERB_MESSAGE(_("Unknown aperture type\n"));
 						return 0;
 				}
 				/* and finally fill the path */
@@ -955,7 +959,7 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 				cairo_restore (cairoTarget);
 				break;
 			default:
-				GERB_MESSAGE("Unknown aperture state\n");
+				GERB_MESSAGE(_("Unknown aperture state\n"));
 				return 0;
 		}
 	    }
