@@ -3,7 +3,7 @@
  * drill.h
  * Copyright (C) 2000-2001 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: drill.h,v 1.14 2008/01/08 00:01:12 thepurlieu Exp $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+/** \file drill.h
+    \brief Header infor for the Excellon drill parsing functions
+    \ingroup libgerbv
+*/
+
 #ifndef DRILL_H
 #define DRILL_H
 
@@ -35,7 +40,8 @@ extern "C" {
 #define TOOL_MIN 1  /* T00 code is reserved for unload tool command */
 #define TOOL_MAX 9999
 
-gerb_image_t *parse_drillfile(gerb_file_t *fd);
+gerbv_image_t *parse_drillfile(gerb_file_t *fd, gerbv_HID_Attribute *attr_list, 
+			      int n_attr, int reload);
 gboolean
 drill_file_p(gerb_file_t *fd, gboolean *returnFoundBinary);
 
