@@ -37,6 +37,7 @@
 
 #include <glib/gstdio.h>
 #include "gerbv.h"
+#include "common.h"
 #include "draw-gdk.h"
 
 /* DEBUG printing.  #define DEBUG 1 in config.h to use this fcn. */
@@ -213,7 +214,7 @@ gerbv_export_rs274x_file_from_image (gchar *filename, gerbv_image_t *inputImage,
 		thisTransform = &identityTransform;
 	}
 	if ((fd = g_fopen(filename, "w")) == NULL) {
-		GERB_MESSAGE("Can't open file for writing: %s\n", filename);
+		GERB_MESSAGE(_("Can't open file for writing: %s\n"), filename);
 		return FALSE;
 	}
 	
@@ -224,7 +225,7 @@ gerbv_export_rs274x_file_from_image (gchar *filename, gerbv_image_t *inputImage,
 	fprintf(fd, "G04 This is an RS-274x file exported by *\n");
 	fprintf(fd, "G04 gerbv version %s *\n",VERSION);
 	fprintf(fd, "G04 More information is available about gerbv at *\n");
-	fprintf(fd, "G04 http://gerbv.gpleda.org/ *\n");
+	fprintf(fd, "G04 http://gerbv.geda-project.org/ *\n");
 	fprintf(fd, "G04 --End of header info--*\n");
 	fprintf(fd, "%%MOIN*%%\n");
 	fprintf(fd, "%%FSLAX34Y34*%%\n");
