@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerb_file.h,v 1.8 2004/09/04 23:45:19 juergenhaas Exp $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+/** \file gerb_file.h
+    \brief Header info for the file parsing support functions
+    \ingroup libgerbv
+*/
+
 #ifndef GERB_FILE_H
 #define GERB_FILE_H
 
@@ -32,10 +37,11 @@ typedef struct file {
     char *data;   /* Pointer to data mmaped in. May not be changed, use ptr */
     int   datalen;/* Length of mmaped data ie file length */
     int   ptr;    /* Index in data where we are reading */
+    char *filename;  /* File name */
 } gerb_file_t;
 
 
-gerb_file_t *gerb_fopen(char *filename);
+gerb_file_t *gerb_fopen(char const* filename);
 int gerb_fgetc(gerb_file_t *fd);
 int gerb_fgetint(gerb_file_t *fd, int *len); /* If len != NULL, returns number
 						of chars parsed in len */
@@ -53,6 +59,6 @@ const char path_separator;
  * characters to / (or string end if no /) is interpreted as a environment
  * variable.
  */
-char *gerb_find_file(char *filename, char **paths);
+char *gerb_find_file(char const * filename, char **paths);
 
 #endif /* GERB_FILE_H */
