@@ -35,6 +35,7 @@
 #include <ctype.h>
 
 #include "config.h"
+#include "common.h"
 #include "gerbv.h"
 #include "gerb_image.h"
 #include "gerber.h"
@@ -175,7 +176,7 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    default:
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
-				     "Unknown M code found.\n",
+				     _("Unknown M code found.\n"),
 				     GERBV_MESSAGE_ERROR);
 	    } /* switch(parse_M_code) */
 	    break;
@@ -485,7 +486,7 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 									 1,
 									 stats->error_list);
 			if (retcode == -1) {
-			    string = g_strdup_printf("Found undefined D code D%d in file \n%s\n", 
+			    string = g_strdup_printf(_("Found undefined D code D%d in file\n%s\n"),
 						     curr_net->aperture, 
 						     fd->filename);
 			    gerbv_stats_add_error(stats->error_list,
@@ -685,8 +686,10 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 					     
 		}
 		/* update the info bounding box with this latest bounding box */
-		gerber_update_image_min_max(&boundingBox, repeat_off_X, repeat_off_Y, image);
-		
+		/* don't change the bounding box if the polarity is clear */
+		if (state->layer->polarity != GERBV_POLARITY_CLEAR){
+			gerber_update_image_min_max(&boundingBox, repeat_off_X, repeat_off_Y, image);
+		}
 		/* optionally update the knockout measurement box */
 		if (knockoutMeasure) {
 			if (boundingBox.left < knockoutLimitXmin)
@@ -717,7 +720,7 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    break;
 	default:
 	    stats->unknown++;
-	    string = g_strdup_printf("Found unknown character (whitespace?) [%d]%c\n", 
+	    string = g_strdup_printf(_("Found unknown character (whitespace?) [%d]%c\n"),
 				     read, read);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
@@ -764,12 +767,12 @@ parse_gerb(gerb_file_t *fd, gchar *directoryPath)
      */
     image = gerbv_create_image(image, "RS274-X (Gerber) File");
     if (image == NULL)
-	GERB_FATAL_ERROR("malloc image failed\n");
+	GERB_FATAL_ERROR(_("malloc image failed\n"));
     curr_net = image->netlist;
     image->layertype = GERBV_LAYERTYPE_RS274X;
     image->gerbv_stats = gerbv_stats_new();
     if (image->gerbv_stats == NULL)
-	GERB_FATAL_ERROR("malloc gerbv_stats failed\n");
+	GERB_FATAL_ERROR(_("malloc gerbv_stats failed\n"));
     stats = (gerbv_stats_t *) image->gerbv_stats;
 
     /* set active layer and netstate to point to first default one created */
@@ -786,7 +789,7 @@ parse_gerb(gerb_file_t *fd, gchar *directoryPath)
 					  fd, directoryPath);
 
     if (!foundEOF) {
-	string = g_strdup_printf("File %s is missing Gerber EOF code.\n", fd->filename);
+	string = g_strdup_printf(_("File %s is missing Gerber EOF code.\n"), fd->filename);
     	gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string,
@@ -827,7 +830,7 @@ gerber_is_rs274x_p(gerb_file_t *fd, gboolean *returnFoundBinary)
     dprintf ("gerber_is_rs274x_p(%p, %p), fd->fd = %p\n", fd, returnFoundBinary, fd->fd); 
     buf = (char *) g_malloc(MAXL);
     if (buf == NULL) 
-	GERB_FATAL_ERROR("malloc buf failed while checking for rs274x.\n");
+	GERB_FATAL_ERROR(_("malloc buf failed while checking for rs274x.\n"));
     
     while (fgets(buf, MAXL, fd->fd) != NULL) {
         dprintf ("buf = \"%s\"\n", buf);
@@ -921,7 +924,7 @@ gerber_is_rs274d_p(gerb_file_t *fd)
     
     buf = malloc(MAXL);
     if (buf == NULL) 
-	GERB_FATAL_ERROR("malloc buf failed while checking for rs274d.\n");
+	GERB_FATAL_ERROR(_("malloc buf failed while checking for rs274d.\n"));
 
     while (fgets(buf, MAXL, fd->fd) != NULL) {
 	len = strlen(buf);
@@ -1054,7 +1057,7 @@ parse_G_code(gerb_file_t *fd, gerb_state_t *state, gerbv_image_t *image)
 	    if ((a >= 0) && (a <= APERTURE_MAX)) {
 		state->curr_aperture = a;
 	    } else { 
-		string = g_strdup_printf("Found aperture D%d out of bounds while parsing G code in file \n%s\n", 
+		string = g_strdup_printf(_("Found aperture D%d out of bounds while parsing G code in file\n%s\n"),
 					 a, fd->filename);
 		gerbv_stats_add_error(stats->error_list,
 				      -1,
@@ -1063,7 +1066,7 @@ parse_G_code(gerb_file_t *fd, gerb_state_t *state, gerbv_image_t *image)
 		g_free(string);
 	    }
 	} else {
-	    string =  g_strdup_printf("Found unexpected code after G54 in file \n%s\n", fd->filename);
+	    string =  g_strdup_printf(_("Found unexpected code after G54 in file\n%s\n"), fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
 				  string, 
@@ -1103,13 +1106,13 @@ parse_G_code(gerb_file_t *fd, gerb_state_t *state, gerbv_image_t *image)
 	stats->G91++;
 	break;
     default:
-	string = g_strdup_printf("Encountered unknown G code G%d in file \n%s\n", op_int, fd->filename);
+	string = g_strdup_printf(_("Encountered unknown G code G%d in file\n%s\n"), op_int, fd->filename);
 	gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string,
 			      GERBV_MESSAGE_ERROR);
 	g_free(string);
-	string = g_strdup_printf("Ignorning unknown G code G%d\n", op_int);
+	string = g_strdup_printf(_("Ignorning unknown G code G%d\n"), op_int);
 	gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string,
@@ -1136,10 +1139,10 @@ parse_D_code(gerb_file_t *fd, gerb_state_t *state, gerbv_image_t *image)
     gchar *string;
 
     a = gerb_fgetint(fd, NULL);
-    dprintf("     In parse_D_code, found D number = %d ... \n", a);
+    dprintf("     In parse_D_code, found D number = %d ...\n", a);
     switch(a) {
     case 0 : /* Invalid code */
-	string = g_strdup_printf("Found invalid D00 code in file \n%s.\n", fd->filename);
+	string = g_strdup_printf(_("Found invalid D00 code in file\n%s\n"), fd->filename);
         gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string, 
@@ -1167,7 +1170,7 @@ parse_D_code(gerb_file_t *fd, gerb_state_t *state, gerbv_image_t *image)
 	    state->curr_aperture = a;
 	    
 	} else {
-	    string = g_strdup_printf("Found out of bounds aperture D%d in file \n%s\n", 
+	    string = g_strdup_printf(_("Found out of bounds aperture D%d in file\n%s\n"),
 				     a, fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
@@ -1205,14 +1208,14 @@ parse_M_code(gerb_file_t *fd, gerbv_image_t *image)
 	stats->M2++;
 	return 3;
     default:
-	string = g_strdup_printf("Encountered unknown M code M%d in file \n%s\n", 
+	string = g_strdup_printf(_("Encountered unknown M code M%d in file\n%s\n"),
 				 op_int, fd->filename);
 	gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string, 
 			      GERBV_MESSAGE_ERROR);
 	g_free(string);
-	string = g_strdup_printf("Ignorning unknown M code M%d\n", op_int);
+	string = g_strdup_printf(_("Ignorning unknown M code M%d\n"), op_int);
 	gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string, 
@@ -1246,7 +1249,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
     op[1] = gerb_fgetc(fd);
     
     if ((op[0] == EOF) || (op[1] == EOF)) {
-	string = g_strdup_printf("Unexpected EOF found in file \n%s\n", fd->filename);
+	string = g_strdup_printf(_("Unexpected EOF found in file\n%s\n"), fd->filename);
 	gerbv_stats_add_error(stats->error_list,
 			      -1,
 			      string, 
@@ -1265,7 +1268,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	state->state = gerbv_image_return_new_netstate (state->state);
 	
 	if ((op[0] == EOF) || (op[1] == EOF)) {
-	    string = g_strdup_printf("Unexpected EOF found in file \n%s\n", fd->filename);
+	    string = g_strdup_printf(_("Unexpected EOF found in file\n%s\n"), fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
 				  string,
@@ -1284,7 +1287,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	op[1] = gerb_fgetc(fd);
 	
 	if ((op[0] == EOF) || (op[1] == EOF)) {
-	    string = g_strdup_printf("Unexpected EOF found in file \n%s\n", fd->filename);
+	    string = g_strdup_printf(_("Unexpected EOF found in file\n%s\n"), fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string, 
@@ -1314,14 +1317,14 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    image->format->omit_zeros = GERBV_OMIT_ZEROS_EXPLICIT;
 	    break;
 	default:
-	    string = g_strdup_printf("EagleCad bug detected: Undefined handling of zeros in format code in file \n%s\n",
+	    string = g_strdup_printf(_("EagleCad bug detected: Undefined handling of zeros in format code in file\n%s\n"),
 				     fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string, 
 				 GERBV_MESSAGE_ERROR);
 	    g_free(string);
-	    string = g_strdup_printf("Defaulting to omitting leading zeros.\n");
+	    string = g_strdup_printf(_("Defaulting to omitting leading zeros.\n"));
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
 				  string,
@@ -1339,14 +1342,14 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    image->format->coordinate = GERBV_COORDINATE_INCREMENTAL;
 	    break;
 	default:
-	    string = g_strdup_printf("Invalid coordinate type defined in format code in file \n%s\n",
+	    string = g_strdup_printf(_("Invalid coordinate type defined in format code in file\n%s\n"),
 				     fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
 				  string, 
 				  GERBV_MESSAGE_ERROR);
 	    g_free(string);
-	    string = g_strdup_printf("Defaulting to absolute coordinates.\n");
+	    string = g_strdup_printf(_("Defaulting to absolute coordinates.\n"));
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string,
@@ -1376,7 +1379,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    case 'X' :
 		op[0] = gerb_fgetc(fd);
 		if ((op[0] < '0') || (op[0] > '6')) {
-		    string = g_strdup_printf("Illegal format size %c in file \n%s\n", 
+		    string = g_strdup_printf(_("Illegal format size %c in file\n%s\n"),
 					     (char)op[0], fd->filename);
 		    gerbv_stats_add_error(stats->error_list,
 					 -1,
@@ -1387,7 +1390,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		image->format->x_int = op[0] - '0';
 		op[0] = gerb_fgetc(fd);
 		if ((op[0] < '0') || (op[0] > '6')) {
-		    string = g_strdup_printf("Illegal format size %c in file \n%s\n", 
+		    string = g_strdup_printf(_("Illegal format size %c in file\n%s\n"),
 					     (char)op[0], fd->filename);
 		    gerbv_stats_add_error(stats->error_list,
 					  -1,
@@ -1400,7 +1403,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    case 'Y':
 		op[0] = gerb_fgetc(fd);
 		if ((op[0] < '0') || (op[0] > '6')) {
-		    string = g_strdup_printf("Illegal format size %c in file \n%s\n", 
+		    string = g_strdup_printf(_("Illegal format size %c in file\n%s\n"),
 					     (char)op[0], fd->filename);
 		    gerbv_stats_add_error(stats->error_list,
 					 -1,
@@ -1411,7 +1414,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		image->format->y_int = op[0] - '0';
 		op[0] = gerb_fgetc(fd);
 		if ((op[0] < '0') || (op[0] > '6')) {
-		    string = g_strdup_printf("Illegal format size %c in file \n%s\n", 
+		    string = g_strdup_printf(_("Illegal format size %c in file\n%s\n"),
 					     (char)op[0], fd->filename);
 		    gerbv_stats_add_error(stats->error_list,
 					 -1,
@@ -1422,14 +1425,14 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		image->format->y_dec = op[0] - '0';
 		break;
 	    default :
-		string = g_strdup_printf("Illegal format statement [%c] in file \n%s\n", 
+		string = g_strdup_printf(_("Illegal format statement [%c] in file\n%s\n"),
 					 op[0], fd->filename);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
 				      string, 
 				     GERBV_MESSAGE_ERROR);
 		g_free(string);
-		string = g_strdup_printf("Ignoring invalid format statement.\n");
+		string = g_strdup_printf(_("Ignoring invalid format statement.\n"));
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
 				      string, 
@@ -1465,7 +1468,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		}
 		break;
 	    default :
-		string =  g_strdup_printf("Wrong character in mirror:%c\n", op[0]);
+		string =  g_strdup_printf(_("Wrong character in mirror:%c\n"), op[0]);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
 				      string,
@@ -1482,7 +1485,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	if ((op[0] == EOF) || (op[1] == EOF))
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
-				 "Unexpected EOF found.\n",
+				 _("Unexpected EOF found.\n"),
 				 GERBV_MESSAGE_ERROR);
 	switch (A2I(op[0],op[1])) {
 	case A2I('I','N'):
@@ -1494,7 +1497,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    state->state->unit = GERBV_UNIT_MM;
 	    break;
 	default:
-	    string = g_strdup_printf("Illegal unit:%c%c\n", op[0], op[1]);
+	    string = g_strdup_printf(_("Illegal unit: %c%c\n"), op[0], op[1]);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string, 
@@ -1514,7 +1517,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		state->state->offsetB = gerb_fgetdouble(fd) / scale;
 		break;
 	    default :
-		string = g_strdup_printf("Wrong character in offset:%c\n", op[0]);
+		string = g_strdup_printf(_("Wrong character in offset: %c\n"), op[0]);
 		gerbv_stats_add_error(stats->error_list,
 				      -1,
 				      string, 
@@ -1543,7 +1546,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 			gerber_parse_file_segment (levelOfRecursion + 1, image, state, curr_net, stats, includefd, directoryPath);
 			gerb_fclose(includefd);
 		    } else {
-			string = g_strdup_printf("In file %s,\nIncluded file %s cannot be found\n",
+			string = g_strdup_printf(_("In file %s,\nincluded file %s cannot be found\n"),
 						 fd->filename, fullPath);
 			gerbv_stats_add_error(stats->error_list, 
 					      -1,
@@ -1553,7 +1556,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		    }
 		    g_free (fullPath);
 		} else {
-		    string = g_strdup_printf("Parser encountered more than 10 levels of include file recursion which is not allowed by the RS-274X spec\n");
+		    string = g_strdup_printf(_("Parser encountered more than 10 levels of include file recursion which is not allowed by the RS-274X spec\n"));
 		    gerbv_stats_add_error(stats->error_list, 
 					  -1,
 					  string, 
@@ -1576,7 +1579,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		image->info->offsetB = gerb_fgetdouble(fd) / scale;
 		break;
 	    default :
-		string = g_strdup_printf("In file %s,\nwrong character in image offset %c\n", 
+		string = g_strdup_printf(_("In file %s,\nwrong character in image offset %c\n"),
 					 fd->filename, op[0]);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
@@ -1608,7 +1611,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	op[1] = gerb_fgetc(fd);
 	
 	if ((op[0] == EOF) || (op[1] == EOF)) {
-	    string = g_strdup_printf("Unexpected EOF found in file \n%s\n", fd->filename);
+	    string = g_strdup_printf(_("Unexpected EOF found in file\n%s\n"), fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string,
@@ -1632,7 +1635,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    image->info->encoding = GERBV_ENCODING_EIA;
 	    break;
 	default:
-	    string = g_strdup_printf("In file %s, \nunknown input code (IC): %c%c\n", 
+	    string = g_strdup_printf(_("In file %s,\nunknown input code (IC): %c%c\n"),
 				     fd->filename, op[0], op[1]);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
@@ -1674,7 +1677,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    	}
 		break;
 	    default :
-		string = g_strdup_printf("In file %s,\nwrong character in image justify:%c\n", 
+		string = g_strdup_printf(_("In file %s,\nwrong character in image justify:%c\n"),
 					 fd->filename, op[0]);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
@@ -1693,7 +1696,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	for (ano = 0; ano < 3; ano++) {
 	    op[0] = gerb_fgetc(fd);
 	    if (op[0] == EOF) {
-		string = g_strdup_printf("In file %s,\nunexpected EOF while reading image polarity (IP)\n",
+		string = g_strdup_printf(_("In file %s,\nunexpected EOF while reading image polarity (IP)\n"),
 					 fd->filename);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
@@ -1709,7 +1712,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	else if (strncmp(str, "NEG", 3) == 0)
 	    image->info->polarity = GERBV_POLARITY_NEGATIVE;
 	else {
-	    string = g_strdup_printf("Unknown polarity : %c%c%c\n", str[0], str[1], str[2]);
+	    string = g_strdup_printf(_("Unknown polarity: %c%c%c\n"), str[0], str[1], str[2]);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string,
@@ -1728,7 +1731,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	else if (tmp == 270)
 	    image->info->imageRotation = 3.0 * M_PI / 2.0;
 	else {
-	    string = g_strdup_printf("Image rotation must be 0, 90, 180 or 270 (is actually %d)\n", tmp);
+	    string = g_strdup_printf(_("Image rotation must be 0, 90, 180 or 270 (is actually %d)\n"), tmp);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
 				  string,
@@ -1759,12 +1762,12 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    gerbv_stats_add_to_D_list(stats->D_code_list,
 				     ano);
 	    if (ano < APERTURE_MIN) {
-		    string = g_strdup_printf("In file %s,\naperture number out of bounds : %d\n", 
+		    string = g_strdup_printf(_("In file %s,\naperture number out of bounds: %d\n"),
 					     fd->filename, ano);
 		    gerbv_stats_add_error(stats->error_list,-1, string, GERBV_MESSAGE_ERROR);
 	    }
 	} else {
-	    string = g_strdup_printf("In file %s,\naperture number out of bounds : %d\n", 
+	    string = g_strdup_printf(_("In file %s,\naperture number out of bounds: %d\n"),
 				     fd->filename, ano);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
@@ -1784,7 +1787,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    print_program(image->amacro);
 #endif
 	} else {
-	    string = g_strdup_printf("In file %s, \nfailed to parse aperture macro\n", 
+	    string = g_strdup_printf(_("In file %s,\nfailed to parse aperture macro\n"),
 				     fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
@@ -1809,7 +1812,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	    state->layer->polarity = GERBV_POLARITY_CLEAR;
 	    break;
 	default:
-	    string = g_strdup_printf("In file %s,\nunknown Layer Polarity: %c\n", 
+	    string = g_strdup_printf(_("In file %s,\nunknown Layer Polarity: %c\n"),
 				     fd->filename, op[0]);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
@@ -1832,7 +1835,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	} else if (op[0] == 'D') {
 	    state->layer->knockout.polarity = GERBV_POLARITY_DARK;
 	} else {
-	    string = g_strdup_printf("In file %s,\nknockout must supply a polarity (C, D, or *)\n",
+	    string = g_strdup_printf(_("In file %s,\nknockout must supply a polarity (C, D, or *)\n"),
 				     fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
@@ -1878,7 +1881,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	        knockoutLayer = state->layer;
 	        break;
 	    default:
-		string = g_strdup_printf("In file %s, \nunknown variable in knockout",
+		string = g_strdup_printf(_("In file %s,\nunknown variable in knockout"),
 					 fd->filename);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
@@ -1915,7 +1918,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 		state->layer->stepAndRepeat.dist_Y = gerb_fgetdouble(fd) / scale;
 		break;
 	    default:
-		string = g_strdup_printf("In file %s,\nstep-and-repeat parameter error\n",
+		string = g_strdup_printf(_("In file %s,\nstep-and-repeat parameter error\n"),
 					 fd->filename);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
@@ -1944,7 +1947,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	state->layer->rotation = gerb_fgetdouble(fd) * M_PI / 180;
 	op[0] = gerb_fgetc(fd);
 	if (op[0] != '*') {
-	    string = g_strdup_printf("In file %s,\nerror in layer rotation command\n",
+	    string = g_strdup_printf(_("In file %s,\nerror in layer rotation command\n"),
 				     fd->filename);
 	    gerbv_stats_add_error(stats->error_list,
 				 -1,
@@ -1954,7 +1957,7 @@ parse_rs274x(gint levelOfRecursion, gerb_file_t *fd, gerbv_image_t *image,
 	}
 	break;
     default:
-	string = g_strdup_printf("In file %s,\nunknown RS-274X extension found %%%c%c%%\n", 
+	string = g_strdup_printf(_("In file %s,\nunknown RS-274X extension found %%%c%c%%\n"),
 				 fd->filename, op[0], op[1]);
 	gerbv_stats_add_error(stats->error_list,
 			     -1,
@@ -2042,15 +2045,15 @@ simplify_aperture_macro(gerbv_aperture_t *aperture, gdouble scale)
     gerbv_simplified_amacro_t *sam;
 
     if (aperture == NULL)
-	GERB_FATAL_ERROR("aperture NULL in simplify aperture macro\n");
+	GERB_FATAL_ERROR(_("aperture NULL in simplify aperture macro\n"));
 
     if (aperture->amacro == NULL)
-	GERB_FATAL_ERROR("aperture->amacro NULL in simplify aperture macro\n");
+	GERB_FATAL_ERROR(_("aperture->amacro NULL in simplify aperture macro\n"));
 
     /* Allocate stack for VM */
     s = new_stack(aperture->amacro->nuf_push + extra_stack_size);
     if (s == NULL) 
-	GERB_FATAL_ERROR("malloc stack failed\n");
+	GERB_FATAL_ERROR(_("malloc stack failed\n"));
 
     /* Make a copy of the parameter list that we can rewrite if necessary */
     lp = g_new (double,APERTURE_PARAMETERS_MAX);
@@ -2069,35 +2072,35 @@ simplify_aperture_macro(gerbv_aperture_t *aperture, gdouble scale)
 	    break;
 	case GERBV_OPCODE_PPOP:
 	    if (pop(s, &tmp[0]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    lp[ip->data.ival - 1] = tmp[0];
 	    break;
 	case GERBV_OPCODE_ADD :
 	    if (pop(s, &tmp[0]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    if (pop(s, &tmp[1]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    push(s, tmp[1] + tmp[0]);
 	    break;
 	case GERBV_OPCODE_SUB :
 	    if (pop(s, &tmp[0]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    if (pop(s, &tmp[1]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    push(s, tmp[1] - tmp[0]);
 	    break;
 	case GERBV_OPCODE_MUL :
 	    if (pop(s, &tmp[0]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    if (pop(s, &tmp[1]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    push(s, tmp[1] * tmp[0]);
 	    break;
 	case GERBV_OPCODE_DIV :
 	    if (pop(s, &tmp[0]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    if (pop(s, &tmp[1]) < 0)
-		GERB_FATAL_ERROR("Tried to pop an empty stack");
+		GERB_FATAL_ERROR(_("Tried to pop an empty stack"));
 	    push(s, tmp[1] / tmp[0]);
 	    break;
 	case GERBV_OPCODE_PRIM :
@@ -2162,7 +2165,10 @@ simplify_aperture_macro(gerbv_aperture_t *aperture, gdouble scale)
 
 	    if (type != GERBV_APTYPE_NONE) { 
 		if (nuf_parameters > APERTURE_PARAMETERS_MAX) {
-		    GERB_COMPILE_ERROR("Number of parameters to aperture macro are more than gerbv is able to store\n");
+			GERB_COMPILE_ERROR(_("Number of parameters to aperture macro (%d) "
+							"are more than gerbv is able to store (%d)\n"),
+							nuf_parameters, APERTURE_PARAMETERS_MAX);
+			nuf_parameters = APERTURE_PARAMETERS_MAX;
 		}
 
 		/*
@@ -2298,7 +2304,7 @@ parse_aperture_definition(gerb_file_t *fd, gerbv_aperture_t *aperture,
     gchar *string;
     
     if (gerb_fgetc(fd) != 'D') {
-	string = g_strdup_printf("Found AD code with no following 'D' in file \n%s\n", 
+	string = g_strdup_printf(_("Found AD code with no following 'D' in file\n%s\n"),
 				 fd->filename);
 	gerbv_stats_add_error(stats->error_list,
 			     -1,
@@ -2320,7 +2326,7 @@ parse_aperture_definition(gerb_file_t *fd, gerbv_aperture_t *aperture,
     token = strtok(ad, ",");
     
     if (token == NULL) {
-		string = g_strdup_printf("Invalid aperture definition in file \n%s\n", 
+		string = g_strdup_printf(_("Invalid aperture definition in file\n%s\n"),
 					 fd->filename);
 		gerbv_stats_add_error(stats->error_list,
 				     -1,
@@ -2368,7 +2374,7 @@ parse_aperture_definition(gerb_file_t *fd, gerbv_aperture_t *aperture,
     for (token = strtok(NULL, "X"), i = 0; token != NULL; 
 	 token = strtok(NULL, "X"), i++) {
 	if (i == APERTURE_PARAMETERS_MAX) {
-	    string = g_strdup_printf("In file %s,\nmaximum number of allowed parameters exceeded in aperture %d\n", 
+	    string = g_strdup_printf(_("In file %s,\nmaximum number of allowed parameters exceeded in aperture %d\n"),
 				     fd->filename, ano);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
@@ -2389,7 +2395,7 @@ parse_aperture_definition(gerb_file_t *fd, gerbv_aperture_t *aperture,
 	
 	aperture->parameter[i] = tempHolder;
 	if (errno) {
-	    string = g_strdup_printf("Failed to read all parameters exceeded in aperture %d\n", ano);
+	    string = g_strdup_printf(_("Failed to read all parameters exceeded in aperture %d\n"), ano);
 	    gerbv_stats_add_error(stats->error_list,
 				  -1,
 				  string,
@@ -2464,7 +2470,7 @@ calc_cirseg_sq(struct gerbv_net *net, int cw,
 	    quadrant = 2;
 	    break;
 	default : 
-	    GERB_COMPILE_ERROR("Unknow quadrant value while converting to cw\n");
+	    GERB_COMPILE_ERROR(_("Unknow quadrant value while converting to cw\n"));
 	}
     }
 
@@ -2489,7 +2495,7 @@ calc_cirseg_sq(struct gerbv_net *net, int cw,
 	net->cirseg->cp_y = net->start_y + delta_cp_y;
 	break;
     default :
-	GERB_COMPILE_ERROR("Strange quadrant : %d\n", quadrant);
+	GERB_COMPILE_ERROR(_("Strange quadrant: %d\n"), quadrant);
     }
 
     /*
@@ -2535,15 +2541,15 @@ calc_cirseg_sq(struct gerbv_net *net, int cw,
 	net->cirseg->angle2 = 360.0 - RAD2DEG(beta);
 	break;
     default :
-	GERB_COMPILE_ERROR("Strange quadrant : %d\n", quadrant);
+	GERB_COMPILE_ERROR(_("Strange quadrant: %d\n"), quadrant);
     }
 
     if (net->cirseg->width < 0.0)
-	GERB_COMPILE_WARNING("Negative width [%f] in quadrant %d [%f][%f]\n", 
+	GERB_COMPILE_WARNING(_("Negative width [%f] in quadrant %d [%f][%f]\n"),
 			     net->cirseg->width, quadrant, alfa, beta);
     
     if (net->cirseg->height < 0.0)
-	GERB_COMPILE_WARNING("Negative height [%f] in quadrant %d [%f][%f]\n", 
+	GERB_COMPILE_WARNING(_("Negative height [%f] in quadrant %d [%f][%f]\n"),
 			     net->cirseg->height, quadrant, RAD2DEG(alfa), RAD2DEG(beta));
 
     return;
