@@ -56,18 +56,17 @@
 
 #include "gerbv.h"
 #include "gerber.h"
+#include "main.h"
 #ifdef RENDER_USING_GDK
   #include "draw-gdk.h"
 #else
   #include "draw.h"
 #endif
 
+#include "common.h"
 #include "csv.h"
 #include "pick-and-place.h"
 
-/* CHECKME - here gi18n is disabled */
-#define _(String) (String)
-
 #undef max
 #define max(a,b) ((a) > (b) ? (a) : (b))
 #undef min
@@ -80,7 +79,7 @@ void gerb_transf_free(gerbv_transf_t *transf)
 {
     g_free(transf);
     
-}/*gerbv_transf_t*/
+}
 
 
 void gerb_transf_reset(gerbv_transf_t* transf)
@@ -92,7 +91,7 @@ void gerb_transf_reset(gerbv_transf_t* transf)
     transf->scale = 1.0;
     //transf->offset[0] = transf->offset[1] = 0.0;
     
-} /*gerb_transf_reset*/
+} /* gerb_transf_reset */
 
 
 gerbv_transf_t* gerb_transf_new(void)
@@ -104,7 +103,7 @@ gerbv_transf_t* gerb_transf_new(void)
     return transf;
     
 
-} /*gerb_transf_new*/
+} /* gerb_transf_new */
 
 
 //!Rotation
@@ -124,7 +123,7 @@ void gerb_transf_rotate(gerbv_transf_t* transf, double angle)
     transf->r_mat[1][1] = s * m[0][1] + c * m[1][1];
 //    transf->offset[0] = transf->offset[1] = 0.0; CHECK ME
     
-} /*gerb_transf_rotate*/
+} /* gerb_transf_rotate */
 
 //!Translation
 /*! append translation to transformation.
@@ -138,7 +137,7 @@ void gerb_transf_shift(gerbv_transf_t* transf, double shift_x, double shift_y)
     transf->offset[0] += shift_x;
     transf->offset[1] += shift_y;
             
-} /*gerb_transf_shift*/
+} /* gerb_transf_shift */
 
 void gerb_transf_apply(double x, double y, gerbv_transf_t* transf, double *out_x, double *out_y)
 {
@@ -151,7 +150,7 @@ void gerb_transf_apply(double x, double y, gerbv_transf_t* transf, double *out_x
     *out_y += transf->offset[1];
     
     
-}/*gerb_transf_apply*/
+} /* gerb_transf_apply */
 
 void
 pick_and_place_reset_bounding_box (gerbv_net_t *net) {
@@ -167,19 +166,35 @@ pick_and_place_get_float_unit(char *str)
 {
     double x = 0.0;
     char unit[41];
+    extern gerbv_screen_t screen;
 
     /* float, optional space, optional unit mm,cm,in,mil */
     sscanf(str, "%lf %40s", &x, unit);
     if(strstr(unit,"in")) {
 	;
+    } else if(strstr(unit, "mil")) {
+	x /= 1000;
     } else if(strstr(unit, "cm")) {
 	x /= 2.54;
-    } else { /* default to mils */
-	x /= 1000;	
+    } else if(strstr(unit, "mm")) {
+	x /= 25.4;
+    } else { /* default to GUI units */
+	switch (screen.unit) {
+	case GERBV_INS:
+	    break;
+	case GERBV_MILS:
+	    x /= 1000;
+	    break;
+	case GERBV_MMS:
+	    x /= 25.4;
+	    break;
+	default:
+	    assert(screen.unit);
+	}
     }
 
     return x;
-} /* pick_and_place_get_float_unit*/
+} /* pick_and_place_get_float_unit */
 
 
 /** search a string for a delimiter.
@@ -222,7 +237,7 @@ pick_and_place_screen_for_delimiter(char *str, int n)
     } else {
 	return -1;
     }
-} /* pnp_screen_for_delimiter */
+} /* pick_and_place_screen_for_delimiter */
 
 
 /**Parses the PNP data.
@@ -431,7 +446,7 @@ pick_and_place_check_file_type(gerb_file_t *fd, gboolean *returnFoundBinary)
 
     buf = malloc(MAXL);
     if (buf == NULL)
-	GERB_FATAL_ERROR("malloc buf failed while checking for pick-place file.\n");
+	GERB_FATAL_ERROR(_("malloc buf failed while checking for pick-place file.\n"));
 
     while (fgets(buf, MAXL, fd->fd) != NULL) {
 	len = strlen(buf);
@@ -564,19 +579,19 @@ pick_and_place_convert_pnp_data_to_image(GArray *parsedPickAndPlaceData, gint bo
 
     image = gerbv_create_image(image, "Pick and Place (X-Y) File");
     if (image == NULL) {
-	GERB_FATAL_ERROR("malloc image failed\n");
+	GERB_FATAL_ERROR(_("malloc image failed\n"));
     }
 	
     image->format = (gerbv_format_t *)g_malloc(sizeof(gerbv_format_t));
     if (image->format == NULL) {
-	GERB_FATAL_ERROR("malloc format failed\n");
+	GERB_FATAL_ERROR(_("malloc format failed\n"));
     }
     memset((void *)image->format, 0, sizeof(gerbv_format_t));
     
     image->layertype = GERBV_LAYERTYPE_PICKANDPLACE;
     stats = gerbv_drill_stats_new();
     if (stats == NULL)
-        GERB_FATAL_ERROR("malloc pick_place_stats failed\n");
+        GERB_FATAL_ERROR(_("malloc pick_place_stats failed\n"));
     image->drill_stats = stats;
 
 
@@ -825,11 +840,11 @@ pick_and_place_convert_pnp_data_to_image(GArray *parsedPickAndPlaceData, gint bo
     
     gerb_transf_free(tr_rot);
     return image;
-} /* pick_and_place_parse_file_to_image */
+} /* pick_and_place_convert_pnp_data_to_image */
 
 
 /*	------------------------------------------------------------------
- *	pick_and_place_parse_file_to_image
+ *	pick_and_place_parse_file_to_images
  *	------------------------------------------------------------------
  *	Description: Renders a pick and place file to a gerb_image.
  *	Notes: The file format should already be verified before calling
@@ -848,5 +863,5 @@ pick_and_place_parse_file_to_images(gerb_file_t *fd, gerbv_image_t **topImage,
 
 		g_array_free (parsedPickAndPlaceData, TRUE);
 	}
-} /* pick_and_place_parse_file_to_image */
+} /* pick_and_place_parse_file_to_images */
 
